/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { Icon, Popup } from "semantic-ui-react";
import React from "react";
import classNames from "classnames";
/**
 * Hint component.
 *
 * @param {React.PropsWithChildren<HintPropsInterface>} props - Props injected to the component.
 * @return {React.ReactElement}
 */
export const Hint = (props) => {
    const { children, className, compact, disabled, hidden, icon, inline, popup, popupOptions } = props;
    const classes = classNames("ui-hint", {
        compact,
        disabled,
        hidden,
        inline: popup ? true : inline,
        popup
    }, className);
    return (React.createElement("div", { className: classes }, popup
        ? (React.createElement(Popup, Object.assign({ trigger: React.createElement(Icon, { color: "grey", floated: "left", name: icon }), content: children }, popupOptions)))
        : (React.createElement(React.Fragment, null,
            icon && React.createElement(Icon, { color: "grey", floated: "left", name: icon }),
            children))));
};
/**
 * Default props for the hint component.
 */
Hint.defaultProps = {
    compact: false,
    icon: "info circle",
    inline: false,
    popup: false,
    popupOptions: {
        basic: true,
        hoverable: true,
        inverted: true,
        position: "bottom left"
    }
};
//# sourceMappingURL=hint.js.map